==> owncloud_6.0.4~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/contacts/l10n/sv.php <==
<?php $TRANSLATIONS = array(
"Contacts" => "Kontakter",
"Save" => "Spara",
"Uploading..." => "Laddar upp...",
"Importing..." => "Importerar...",
"Preparing..." => "Förbereder...",
"Imported {count} of {total} contacts" => "Importerade {count} av {total} kontakter",
"Imported {imported} contacts. {failed} failed." => "Importerade {imported} kontakter. {failed} misslyckades.",
"An address book called {name} already exists" => "En adressbok vid namn {name} finns redan",
"Failed adding address book: {error}" => "Kan inte lägga till adressbok: {error}",
"Failed loading address books: {error}" => "Misslyckades ladda adressböcker: {error}",
"Indexing contacts" => "Indexerar kontakter",
"Unrecoverable error loading address books: {msg}" => "Irreparabelt fel när adressböckerna skulle laddas: {msg}",
"Error." => "Fel.",
"Add to..." => "Lägga till...",
"Remove from..." => "Ta bort från...",
"Add group..." => "Lägg till grupp...",
"Invalid URL: \"{url}\"" => "Felaktig URL: \"{url}\"",
"There was an error opening a mail composer." => "Fel uppstod när e-postklient skulle öppnas.",
"Invalid email: \"{url}\"" => "Felaktig e-post: \"{url}\"",
"Merge failed. Cannot find contact: {id}" => "Sammanslagning misslyckades. Kan inte hitta kontakt: {id}",
"Merge failed." => "Sammanslagning misslyckades.",
"Merge failed. Error saving contact." => "Sammanslagning misslyckades: Fel vid sparande av kontakt.",
"Select photo" => "Välj foto",
"Network or server error. Please inform administrator." => "Nätverk eller serverfel. Informera administratören.",
"Error adding to group." => "Fel vid tillägg i grupp.",
"Error removing from group." => "Fel vid radering från grupp.",
"Error setting {name} as favorite." => "Fel när {name} skulle läggas till favoriter.",
"Merge contacts" => "Sammanfoga kontakter",
"Cancel" => "Avbryt",
"Add group" => "Lägg till grupp",
"OK" => "OK",
"Could not find contact: {id}" => "Kunde inte hitta kontakt: {id}",
"No files selected for upload." => "Inga filer valda för uppladdning",
"The file you are trying to upload exceed the maximum size for file uploads on this server." => "Filen du försöker ladda upp är större än den maximala storleken för filöverföring på denna server.",
"Edit profile picture" => "Anpassa profilbild",
"Crop photo" => "Beskär bild",
"Is this correct?" => "Är detta korrekt?",
"Error parsing date: {date}" => "Fel vid läsning av datum: {date}",
"# groups" => "# grupper",
"Error parsing birthday {bday}: {error}" => "Fel uppstod under inläsning av födelsedag {bday}: {error}",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "Vissa kontakter är markerade för radering, men är inte raderade än. Vänta tills att de har raderats.",
"Click to undo deletion of {num} contacts" => "Klicka för att ångra radering av {num} kontakter",
"Cancelled deletion of {num} contacts" => "Avbruten radering av {num} kontakter",
"Add" => "Lägg till",
"Contact is already in this group." => "Kontakten finns redan i denna grupp.",
"Contacts are already in this group." => "Kontakterna finns redan i denna grupp.",
"Couldn't get contact list." => "Kunde inte hämta kontaktlista.",
"Contact is not in this group." => "Kontakten är inte i denna grupp.",
"Contacts are not in this group." => "Kontakterna är inte i denna grupp.",
"Failed renaming group: {error}" => "Det gick inte att ändra namn på gruppen: {error}",
"A group named {group} already exists" => "En grupp men namnet {group} finns redan",
"You can drag groups to\narrange them as you like." => "Du kan dra och släppa grupper⏎\nför att arrangera dem som du vill.",
"Failed adding group: {error}" => "Det gick inte att lägga till gruppen :{error}",
"All" => "Alla",
"Favorites" => "Favoriter",
"Shared by {owner}" => "Delad av {owner}",
"Not grouped" => "Inte grupperad.",
"Failed loading groups: {error}" => "Kan inte ladda grupper: {error}",
"Please choose the addressbook" => "Vänligen välj adressboken",
"Import into..." => "Importera till...",
"Error loading import template" => "Fel uppstod under import av mall",
"Import contacts" => "Importera kontakter",
"Import" => "Importera",
"Import done" => "Import klar",
"Close" => "Stäng",
"Error" => "Fel",
"Displayname cannot be empty." => "Visningsnamn får inte vara tomt.",
"Show CardDav link" => "Visa CardDav-länk",
"Show read-only VCF link" => "Visa skrivskyddad VCF-länk",
"Download" => "Ladda ner",
"Edit" => "Redigera",
"Delete" => "Radera",
"More..." => "Mer...",
"Less..." => "Mindre...",
"Server error! Please inform system administator" => "Serverfel! Vänligen Informera administratören.",
"Failed loading photo: {error}" => "Kan inte ladda foton:{error}",
"You do not have permissions to see this contacts" => "Du saknar behörighet för att se denna kontakt",
"Contact not found" => "Kontakten kunde inte hittas",
"You do not have permissions to see these contacts" => "Du saknar behörighet för att kunna se dessa kontakter.",
"You do not have permissions add contacts to the address book" => "Du saknar behörighet för att lägga till kontakter i denna adressbok.",
"The backend for this address book does not support adding contacts" => "Gränssnittet för denna adressbok saknar stöd för att lägga till kontakter.",
"You do not have permissions to delete this contact" => "Du saknar behörighet att ta bort denna kontakt",
"The backend for this address book does not support deleting contacts" => "Gränssnittet för denna adressbok saknar stöd för att ta bort kontakter. ",
"Unknown error" => "Okänt fel",
"The backend for this address book does not support updating" => "Gränssnittet för denna adressbok saknar stöd för uppdateringar",
"You don't have permissions to update the address book." => "Du saknar behörighet att uppdatera adressboken.",
"You don't have permissions to delete the address book." => "Du saknar behörighet att ta bort adressboken.",
"Address book not found" => "Kan inte hitta adressboken.",
"You do not have permissions to see this contact" => "Du saknar behörighet att se denna kontakt",
"You do not have permissions to update this contact" => "Du har inte behörighet att uppdatera denna kontakt",
"The backend for this contact does not support updating it" => "Gränssnittet för denna kontakt saknar stöd för uppdatering av den.",
"This backend not support adding contacts" => "Detta gränssnitt saknar stöd för att lägga till kontakter",
"Property not found" => "Egenskap kunde inte hittas",
" Missing IM parameter for: " => "IM-parametrar saknas för:",
"Unknown IM: " => "Okänt IM:",
"{name}'s Birthday" => "{name}'s födelsedag",
"Error creating address book" => "Fel vid skapandet av adressbok",
"Error updating address book" => "Fel vid uppdatering av adressbok",
"You do not have permissions to delete the \"%s\" address book" => "Du har inte behörighet att radera \"%s\" adressbok",
"Error deleting address book" => "Fel när adressbok skulle raderas",
"Error creating contact." => "Fel vid skapandet av kontakt",
"Error deleting contact." => "Fel när kontakt skulle raderas.",
"Error retrieving contact." => "Fel när kontakt skulle hämtas.",
"Error saving contact." => "Fel vid spara kontakt.",
"Error removing contact from other address book." => "Fel vid borttagning av kontakt från den andra adressboken.",
"Couldn't find contact." => "Kunde inte hitta kontakt.",
"No contact data in request." => "Ingen kontakt data i efterfrågan.",
"Error merging into contact." => "Fel vid sammanslagning till kontakt",
"Error saving contact to backend." => "Fel när kontakt ska sparas till server.",
"Property name is not set." => "Namn för egenskap ej definierat",
"Property checksum is not set." => "Kontrollsumma för objekt ej definierat.",
"Information about vCard is incorrect. Please reload the page." => "Information om vCard är felaktigt. Vänligen ladda om sidan.",
"Error updating contact" => "Fel uppstod när kontakt skulle uppdateras",
"Error saving contact to backend" => "Fel när kontakt skulle sparas till server",
"Error getting user photo" => "Fel uppstod under hämtning av användarbild",
"No file was uploaded. Unknown error" => "Ingen fil har laddats upp. Okänt fel",
"There is no error, the file uploaded with success" => "Inga fel har uppstått. Filen har laddats upp utan problem.",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Den uppladdade filen överskrider värdet för upload_max_filesize i php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Den uppladdade filen överskrider värdet för MAX_FILE_SIZE som har angivits i HTML-formuläret",
"The uploaded file was only partially uploaded" => "Den uppladdade filen har endast delvis laddats upp",
"No file was uploaded" => "Ingen fil har laddats upp",
"Missing a temporary folder" => "Temporär-mapp saknas",
"Couldn't load temporary image: " => "Kan inte ladda tillfällig bild:",
"Couldn't save temporary image: " => "Kan inte spara tillfällig bild:",
"No photo path was submitted." => "Ingen sökväg till foto angavs.",
"File doesn't exist:" => "Filen finns inte:",
"Error loading image." => "Fel vid laddning av bild.",
"Image has been removed from cache" => "Bild har tagits bort från cache",
"Error creating temporary image" => "Fel vid skapa tillfällig bild",
"Error cropping image" => "Fel vid beskärning av bilden",
"Error resizing image" => "Fel vid storleksförändring av bilden",
"Error getting PHOTO property." => "Fel vid hämtning av egenskaper för FOTO.",
"No group name given." => "Inget gruppnamn angivet.",
"Error adding group." => "Fel uppstod när grupp skulle läggas till.",
"No group name to rename from given." => "Inget gruppnamn att byta från angivet.",
"No group name to rename to given." => "Inget gruppnamn att byta till angivet.",
"Error renaming group." => "Fel vid omdöpning av grupp.",
"Group ID missing from request." => "Grupp-ID fattas från anrop.",
"Group name missing from request." => "Gruppnamn saknas från begäran.",
"Contact ID missing from request." => "Kontakt-ID fattas från anrop.",
"Failed to write to disk" => "Misslyckades att spara till disk",
"Not enough storage available" => "Det finns inte tillräckligt med lagringsutrymme",
"Attempt to upload blacklisted file:" => "Försök att ladda upp svartlistad fil:",
"Error uploading contacts to storage." => "Fel uppstod när kontakter sparades.",
"Error moving file to imports folder." => "Fel uppstod när fil skulle flyttas till importmappen.",
"You do not have permissions to import into this address book." => "Du har inte behörighet att importera denna adressbok.",
"File name missing from request." => "Filnamn saknas från begäran.",
"Progress key missing from request." => "Progress-nyckel saknas från begäran.",
"Attempt to access blacklisted file:" => "Försök att komma åt svartlistad fil:",
"No contacts found in: " => "Hittade inga kontakter i:",
"No key is given." => "Ingen nyckel angavs.",
"No value is given." => "Inget värde angavs.",
"Could not set preference: " => "Kan inte ange inställning:",
"Contact" => "Kontakt",
"Other" => "Annat",
"HomePage" => "Hemsida",
"Jabber" => "Jabber",
"Internet call" => "Internetsamtal",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "GoogleTalk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"Work" => "Arbete",
"Home" => "Hem",
"Mobile" => "Mobil",
"Text" => "Text",
"Voice" => "Röst",
"Message" => "Meddelande",
"Fax" => "Fax",
"Video" => "Video",
"Pager" => "Personsökare",
"Internet" => "Internet",
"Friends" => "Vänner",
"Family" => "Familj",
"New Contact" => "Ny kontakt",
"Group name" => "Gruppnamn",
"New Group" => "Ny grupp",
"Address books" => "Adressböcker",
"Display name" => "Visningsnamn",
"Add Address Book" => "Lägg till adressbok",
"Select file..." => "Välj fil...",
"(De-)select all" => "(Av-)markera alla",
"Sort order" => "Sorteringsordning",
"First- Lastname" => "För- Efternamn",
"Last-, Firstname" => "Efter-, Förnamn",
"Groups" => "Grupper",
"Favorite" => "Favorit",
"Merge selected" => "Slå ihop valda",
"Keyboard shortcuts" => "Kortkommandon",
"Navigation" => "Navigering",
"Next contact in list" => "Nästa kontakt i listan",
"Previous contact in list" => "Föregående kontakt i listan",
"Expand/collapse current addressbook" => "Visa/dölj aktuell adressbok",
"Next addressbook" => "Nästa adressbok",
"Previous addressbook" => "Föregående adressbok",
"Actions" => "Åtgärder",
"Refresh contacts list" => "Uppdatera kontaktlistan",
"Add new contact" => "Lägg till ny kontakt",
"Add new addressbook" => "Lägg till ny adressbok",
"Delete current contact" => "Radera denna kontakt",
"<h3>You have no contacts in your address book or your address book is disabled.</h3><p>Add a new contact or import existing contacts from a VCF file.</p>" => "<h3>Du har antingen inga kontakter i din adressbok eller så är din adressboken inaktiverad.</h3><p>Lägg till en ny kontakt eller importera befintliga kontakter från en VCF-fil.</p>",
"Add contact" => "Lägg till en kontakt",
"Delete group" => "Radera grupp",
"Rename group" => "Döp om grupp",
"Which contact should the data be merged into?" => "Vilken kontakt ska informationen slås ihop med?",
"Delete the other(s) after successful merge?" => "Radera dom andra efter lyckad sammanslagning?",
"Compose mail" => "Skapa e-post",
"Delete current photo" => "Ta bort aktuellt foto",
"Edit current photo" => "Redigera aktuellt foto",
"Upload new photo" => "Ladda upp ett nytt foto",
"Select photo from ownCloud" => "Välj foto från ownCloud",
"Name" => "Namn",
"First name" => "Förnamn",
"Additional names" => "Mellannamn",
"Last name" => "Efternamn",
"Select groups" => "Välj grupper",
"Select address book" => "Välj adressbok",
"Nickname" => "Smeknamn",
"Enter nickname" => "Ange smeknamn",
"Title" => "Rubrik",
"Enter title" => "Ange titel",
"Organization" => "Organisation",
"Enter organization" => "Ange organisation",
"Birthday" => "Födelsedag",
"Notes go here..." => "Noteringar här...",
"Export as VCF" => "Exportera som VCF",
"Add field..." => "Lägg till fält...",
"Phone" => "Telefon",
"Email" => "E-post",
"Instant Messaging" => "Instant Messaging",
"Address" => "Adress",
"Note" => "Notering",
"Web site" => "Webbplats",
"Delete contact" => "Radera kontakt",
"Preferred" => "Föredragen",
"Please specify a valid email address." => "Vänligen ange en giltig e-postadress.",
"someone@example.com" => "någon@exempel.com",
"Mail to address" => "Posta till adress.",
"Delete email address" => "Ta bort e-postadress",
"Enter phone number" => "Ange telefonnummer",
"Delete phone number" => "Ta bort telefonnummer",
"Go to web site" => "Gå till webbplats",
"Delete URL" => "Radera URL",
"View on map" => "Visa på karta",
"Delete address" => "Radera adress",
"1600 Pennsylvania Avenue, NW" => "1600 Pennsylvania Avenue, NW",
"Street address" => "Gatuadress",
"20500" => "20500",
"Postal code" => "Postnummer",
"Washington, DC" => "Washington, DC",
"City" => "Stad",
"District of Columbia" => "District of Columbia",
"State or province" => "Stat eller provins",
"USA" => "USA",
"Country" => "Land",
"Instant Messenger" => "Instant Messenger",
"Delete IM" => "Radera IM",
"Active" => "Aktiv",
"Share" => "Dela",
"Export" => "Exportera",
"CardDAV link" => "CardDAV-länk",
"CardDAV syncing addresses" => "CardDAV synkningsadresser",
"more info" => "mer information",
"Primary address (Kontact et al)" => "Primary address (Kontact et al)",
"iOS/OS X" => "iOS/OS X",
"Addressbooks" => "Adressböcker",
"New Address Book" => "Ny adressbok",
"Description" => "Beskrivning"
);

==> owncloud_7.0.0~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/contacts/l10n/sv.php <==
<?php $TRANSLATIONS = array(
"Contacts" => "Kontakter",
"Add new LDAP Addressbook" => "Lägg till ny LDAP adressbok",
"Ok" => "Ok",
"Cancel" => "Avbryt",
"Save" => "Spara",
"Edit Addressbook" => "Redigera adressbok",
"Starting file import" => "Startar fil import",
"Format selected: {format}" => "Format valt: {format}",
"Automatic format detection" => "Automatisk detektering av format",
"Processing {count}/{total} cards" => "Bearbetar {count}/{total} kort",
"Total:{total}, Success:{imported}, Errors:{failed}" => "Totalt:{total}, Lyckades:{imported}, Fel:{failed}",
"An address book called {name} already exists" => "En adressbok vid namn {name} finns redan",
"Failed adding address book: {error}" => "Kan inte lägga till adressbok: {error}",
"Failed loading address books: {error}" => "Misslyckades ladda adressböcker: {error}",
"Server error! Please inform system administator" => "Serverfel! Vänligen Informera administratören.",
"Indexing contacts" => "Indexerar kontakter",
"Unrecoverable error loading address books: {msg}" => "Irreparabelt fel när adressböckerna skulle laddas: {msg}",
"Error." => "Fel.",
"Add to..." => "Lägga till...",
"Remove from..." => "Ta bort från...",
"Add group..." => "Lägg till grupp...",
"Invalid URL: \"{url}\"" => "Felaktig URL: \"{url}\"",
"Invalid email: \"{url}\"" => "Felaktig e-post: \"{url}\"",
"Merge failed. Cannot find contact: {id}" => "Sammanslagning misslyckades. Kan inte hitta kontakt: {id}",
"Merge failed." => "Sammanslagning misslyckades.",
"Merge failed. Error saving contact." => "Sammanslagning misslyckades: Fel vid sparande av kontakt.",
"Select photo" => "Välj foto",
"Network or server error. Please inform administrator." => "Nätverk eller serverfel. Informera administratören.",
"Only images can be used as contact photos" => "Endast bilder kan användas som kontakt foton",
"The size of \"{filename}\" exceeds the maximum allowed {size}" => "Storleken på \"{filname}\" överskrider den maximalt tillåtna {size}",
"Error adding to group." => "Fel vid tillägg i grupp.",
"Error removing from group." => "Fel vid radering från grupp.",
"You have selected over 300 contacts.\nThis will most likely fail! Click here to try anyway." => "Du har valt mer än 300 kontakter.\nDetta kommer troligen misslyckas! Klicka här för att försöka i alla fall.",
"Error setting {name} as favorite." => "Fel när {name} skulle läggas till favoriter.",
"Merge contacts" => "Sammanfoga kontakter",
"Add group" => "Lägg till grupp",
"OK" => "OK",
"Could not find contact: {id}" => "Kunde inte hitta kontakt: {id}",
"Edit profile picture" => "Anpassa profilbild",
"Crop photo" => "Beskär bild",
"Error parsing date: {date}" => "Fel vid läsning av datum: {date}",
"# groups" => "# grupper",
"Error parsing birthday {bday}" => "Fel uppstod under inläsning av födelsedag {bday}",
"The backend does not support multi-byte characters." => "Backend saknar stöd för multi-byte tecken.",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "Vissa kontakter är markerade för radering, men är inte raderade än. Vänta tills att de har raderats.",
"Click to undo deletion of {num} contacts" => "Klicka för att ångra radering av {num} kontakter",
"Cancelled deletion of {num} contacts" => "Avbruten radering av {num} kontakter",
"Add" => "Lägg till",
"Contact is already in this group." => "Kontakten finns redan i denna grupp.",
"Contacts are already in this group." => "Kontakterna finns redan i denna grupp.",
"Couldn't get contact list." => "Kunde inte hämta kontaktlista.",
"Contact is not in this group." => "Kontakten är inte i denna grupp.",
"Contacts are not in this group." => "Kontakterna är inte i denna grupp.",
"A group named \"{group}\" already exists" => "En grupp med namnet \"{group}\" finns redan",
"Failed renaming group: {error}" => "Det gick inte att ändra namn på gruppen: {error}",
"You can drag groups to\narrange them as you like." => "Du kan dra och släppa grupper⏎\nför att arrangera dem som du vill.",
"Failed adding group: {error}" => "Det gick inte att lägga till gruppen :{error}",
"All" => "Alla",
"Favorites" => "Favoriter",
"Shared by {owner}" => "Delad av {owner}",
"Not grouped" => "Inte grupperad.",
"Failed loading groups: {error}" => "Kan inte ladda grupper: {error}",
"Please choose the addressbook" => "Vänligen välj adressboken",
"Import into..." => "Importera till...",
"Error loading import template" => "Fel uppstod under import av mall",
"Import contacts" => "Importera kontakter",
"Import" => "Importera",
"Importing..." => "Importerar...",
"Import done" => "Import klar",
"Close" => "Stäng",
"Error, missing parameters: " => "Fel, parametrar saknas:",
"Failed loading photo: {error}" => "Kan inte ladda foton:{error}",
"You do not have permissions to see this contact" => "Du saknar behörighet att se denna kontakt",
"Contact not found" => "Kontakten kunde inte hittas",
"You do not have permissions to see these contacts" => "Du saknar behörighet för att kunna se dessa kontakter.",
"You do not have permissions add contacts to the address book" => "Du saknar behörighet för att lägga till kontakter i denna adressbok.",
"The backend for this address book does not support adding contacts" => "Gränssnittet för denna adressbok saknar stöd för att lägga till kontakter.",
"You do not have permissions to delete this contact" => "Du saknar behörighet att ta bort denna kontakt",
"The backend for this address book does not support deleting contacts" => "Gränssnittet för denna adressbok saknar stöd för att ta bort kontakter. ",
"Unknown error" => "Okänt fel",
"Access denied" => "Åtkomst nekas",
"The backend for this address book does not support updating" => "Gränssnittet för denna adressbok saknar stöd för uppdateringar",
"You don't have permissions to delete the address book." => "Du saknar behörighet att ta bort adressboken.",
"Address book not found" => "Kan inte hitta adressboken.",
"You do not have permissions to update this contact" => "Du har inte behörighet att uppdatera denna kontakt",
"The backend for this contact does not support updating it" => "Gränssnittet för denna kontakt saknar stöd för uppdatering av den.",
"This backend does not support adding contacts" => "Detta bakomliggande system stödjer inte att kontakter läggs till",
"Property not found" => "Egenskap kunde inte hittas",
" Missing IM parameter for: " => "IM-parametrar saknas för:",
"Unknown IM: " => "Okänt IM:",
"{name}'s Birthday" => "{name}'s födelsedag",
"Error creating address book" => "Fel vid skapandet av adressbok",
"The \"%s\" backend does not support deleting address books" => "\"%s\"  backend saknar stöd för att ta bort adressböcker",
"You do not have permissions to delete the \"%s\" address book" => "Du har inte behörighet att radera \"%s\" adressbok",
"Error deleting address book" => "Fel när adressbok skulle raderas",
"Error creating contact." => "Fel vid skapandet av kontakt",
"Error creating contact" => "Fel vid skapandet av kontakt",
"Error deleting contact" => "Fel när kontakt skulle raderas",
"Error retrieving contact" => "Fel när kontakt skulle hämtas",
"Error saving contact" => "Fel vid sparande av kontakt",
"Error removing contact from other address book." => "Fel vid borttagning av kontakt från den andra adressboken.",
"Error getting moved contact" => "Fel vid flytt av kontakt",
"Couldn't find contact." => "Kunde inte hitta kontakt.",
"No contact data in request." => "Ingen kontakt data i efterfrågan.",
"Error merging into contact." => "Fel vid sammanslagning till kontakt",
"Error saving contact to backend." => "Fel när kontakt ska sparas till server.",
"Property name is not set." => "Namn för egenskap ej definierat",
"Property checksum is not set." => "Kontrollsumma för objekt ej definierat.",
"Information about vCard is incorrect. Please reload the page." => "Information om vCard är felaktigt. Vänligen ladda om sidan.",
"Error updating contact" => "Fel uppstod när kontakt skulle uppdateras",
"Error saving contact to backend" => "Fel när kontakt skulle sparas till server",
"Error getting user photo" => "Fel uppstod under hämtning av användarbild",
"No photo path was submitted." => "Ingen sökväg till foto angavs.",
"Error loading image from cache" => "fel uppstod när bild laddades från cache",
"Error getting PHOTO property." => "Fel vid hämtning av egenskaper för FOTO.",
"Error saving contact." => "Fel vid spara kontakt.",
"No group name given." => "Inget gruppnamn angivet.",
"Error adding group." => "Fel uppstod när grupp skulle läggas till.",
"No group name to rename from given." => "Inget gruppnamn att byta från angivet.",
"No group name to rename to given." => "Inget gruppnamn att byta till angivet.",
"Error renaming group." => "Fel vid omdöpning av grupp.",
"Group ID missing from request." => "Grupp-ID fattas från anrop.",
"Group name missing from request." => "Gruppnamn saknas från begäran.",
"Contact ID missing from request." => "Kontakt-ID fattas från anrop.",
"No file was uploaded. Unknown error" => "Ingen fil har laddats upp. Okänt fel",
"There is no error, the file uploaded with success" => "Inga fel har uppstått. Filen har laddats upp utan problem.",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Den uppladdade filen överskrider värdet för upload_max_filesize i php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Den uppladdade filen överskrider värdet för MAX_FILE_SIZE som har angivits i HTML-formuläret",
"The uploaded file was only partially uploaded" => "Den uppladdade filen har endast delvis laddats upp",
"No file was uploaded" => "Ingen fil har laddats upp",
"Missing a temporary folder" => "Temporär-mapp saknas",
"Failed to write to disk" => "Misslyckades att spara till disk",
"Not enough storage available" => "Det finns inte tillräckligt med lagringsutrymme",
"Attempt to upload blacklisted file:" => "Försök att ladda upp svartlistad fil:",
"Error uploading contacts to storage." => "Fel uppstod när kontakter sparades.",
"Error moving file to imports folder." => "Fel uppstod när fil skulle flyttas till importmappen.",
"You do not have permissions to import into this address book." => "Du har inte behörighet att importera denna adressbok.",
"File name missing from request." => "Filnamn saknas från begäran.",
"Progress key missing from request." => "Progress-nyckel saknas från begäran.",
"Attempt to access blacklisted file:" => "Försök att komma åt svartlistad fil:",
"No key is given." => "Ingen nyckel angavs.",
"No value is given." => "Inget värde angavs.",
"Could not set preference: " => "Kan inte ange inställning:",
"Contact" => "Kontakt",
"Other" => "Annat",
"HomePage" => "Hemsida",
"Jabber" => "Jabber",
"Internet call" => "Internetsamtal",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "GoogleTalk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"ownCloud" => "ownCloud",
"Work" => "Arbete",
"Home" => "Hem",
"Mobile" => "Mobil",
"Text" => "Text",
"Voice" => "Röst",
"Message" => "Meddelande",
"Fax" => "Fax",
"Video" => "Video",
"Pager" => "Personsökare",
"Internet" => "Internet",
"Friends" => "Vänner",
"Family" => "Familj",
"Enable LDAP Backend" => "Aktivera LDAP Backend",
"Enable LDAP backend for the contacts application" => "Aktivera LDAP backend för kontakter-applikationen",
"Warning: LDAP Backend is in beta mode, use with precautions" => "Varning: LDAP Backend är i betaläge, använd med försiktighet",
"New contact" => "Ny kontakt",
"Group name" => "Gruppnamn",
"New group" => "Ny grupp",
"Address books" => "Adressböcker",
"Display name" => "Visningsnamn",
"Add Address Book" => "Lägg till adressbok",
"Add LDAP Address Book" => "Lägg till LDAP-adressbok",
"Automatic format" => "Automatiskt format",
"Select file..." => "Välj fil...",
"(De-)select all" => "(Av-)markera alla",
"Sort order" => "Sorteringsordning",
"First- Lastname" => "För- Efternamn",
"Last-, Firstname" => "Efter-, Förnamn",
"Delete" => "Radera",
"Groups" => "Grupper",
"Download" => "Ladda ner",
"Merge" => "Sammanfoga",
"Email" => "E-post",
"Phone" => "Telefon",
"Address" => "Adress",
"Group" => "Grupp",
"Keyboard shortcuts" => "Kortkommandon",
"Navigation" => "Navigering",
"Next contact in list" => "Nästa kontakt i listan",
"Previous contact in list" => "Föregående kontakt i listan",
"Expand/collapse current addressbook" => "Visa/dölj aktuell adressbok",
"Next addressbook" => "Nästa adressbok",
"Previous addressbook" => "Föregående adressbok",
"Actions" => "Åtgärder",
"Refresh contacts list" => "Uppdatera kontaktlistan",
"Add new contact" => "Lägg till ny kontakt",
"Add new addressbook" => "Lägg till ny adressbok",
"Delete current contact" => "Radera denna kontakt",
"You have no contacts in your address book or your address book is disabled." => "Du har inga kontakter i din adressbok eller så är din adressbok inaktiverad.",
"Add a new contact or import existing contacts from a VCF file." => "Lägg till en ny kontakt eller importera från en en VCF-fil.",
"Which contact should the data be merged into?" => "Vilken kontakt ska informationen slås ihop med?",
"Delete the other(s) after successful merge?" => "Radera dom andra efter lyckad sammanslagning?",
"Compose mail" => "Skapa e-post",
"Delete current photo" => "Ta bort aktuellt foto",
"Edit current photo" => "Redigera aktuellt foto",
"Upload new photo" => "Ladda upp ett nytt foto",
"Select photo from Files" => "Välj foto från Filer",
"Favorite" => "Favorit",
"Name" => "Namn",
"First name" => "Förnamn",
"Additional names" => "Mellannamn",
"Last name" => "Efternamn",
"Address book" => "Adressbok",
"Nickname" => "Smeknamn",
"Title" => "Rubrik",
"Organization" => "Organisation",
"Birthday" => "Födelsedag",
"Website" => "Webbplats",
"Instant messaging" => "Snabbmeddelanden",
"Notes go here..." => "Noteringar här...",
"Add field..." => "Lägg till fält...",
"Instant Messaging" => "Instant Messaging",
"Note" => "Notering",
"Web site" => "Webbplats",
"Preferred" => "Föredragen",
"Please specify a valid email address." => "Vänligen ange en giltig e-postadress.",
"someone@example.com" => "någon@exempel.com",
"Mail to address" => "Posta till adress.",
"Delete email address" => "Ta bort e-postadress",
"Enter phone number" => "Ange telefonnummer",
"Go to web site" => "Gå till webbplats",
"View on map" => "Visa på karta",
"Street address" => "Gatuadress",
"Postal code" => "Postnummer",
"City" => "Stad",
"State or province" => "Stat eller provins",
"Country" => "Land",
"Instant Messenger" => "Instant Messenger",
"Active" => "Aktiv",
"Share" => "Dela",
"Export" => "Exportera",
"CardDAV link" => "CardDAV-länk",
"Edit" => "Redigera",
"Addressbook URI" => "Adressbok URI",
"URI" => "URI",
"Description" => "Beskrivning",
"LDAP URL" => "LDAP URL",
"Anonymous" => "Anonym",
"Read-only" => "Skrivskyddad",
"Read-Only" => "Skrivskyddad",
"User" => "Användare",
"Password" => "Lösenord",
"Page size" => "sidstorlek",
"Base DN for search" => "Base DN för sök",
"Base DN" => "Start DN",
"Search filter" => "Sökfilter",
"Filter" => "Filter",
"Base DN for modification" => "Bas DN för modifiering",
"Base DN modification" => "Base DN modifiering",
"Connector" => "Connector",
"Connector value (Better use external editor and copy/paste)" => "Anslutning värde (Bättre använda extern redigerare och kopiera / klistra in)",
"Copy from (Warning, replaces current custom value)" => "Kopiera från (Varning, ersätter nuvarande anpassade värde)"
);
